@ECHO OFF
REM **************************************************************************
REM 
REM   Module: install.cmd
REM 
REM   Purpose: Install secRMM message dll named secRMMSCCMMsgs.dll into the
REM			   SCCM site server.  This is done by modifying the SCCM site
REM			   control file.
REM 
REM   See the secRMM SCCM 2012 Administrators Guide, section:
REM   "Installation ->
REM        SCCM SECRMM STATUS MESSAGES ->
REM            Step 1 - Setting up the SCCM site server"
REM
REM	  The SQL command to view the SCCM site control file is:
REM   SELECT SiteControl FROM vSMS_SC_SiteControlXML WHERE SiteCode = 'XXX'
REM   where XXX is the 3 letter site code
REM
REM   Copyright (c) 2015 Squadra Technologies 
REM    
REM **************************************************************************

@ECHO OFF
SETLOCAL EnableDelayedExpansion

SET InstallDrive=%~d0
SET InstallDir=%~dp0

SET BaseSCCMDir=

SET KEY_NAME64=HKLM\SOFTWARE\Wow6432Node\Microsoft\ConfigMgr10\Setup
SET KEY_NAME32=HKLM\SOFTWARE\Microsoft\ConfigMgr10\Setup
SET VALUE_NAME="UI Installation Directory"
SET ADMINCONSOLEPATH=\Microsoft Configuration Manager\AdminConsole\

FOR /F "usebackq skip=2 tokens=3,4*" %%A IN (`REG QUERY %KEY_NAME64% /v %VALUE_NAME% 2^>nul`) DO (
    set BaseSCCMDir=%%C
)

IF NOT EXIST "%BaseSCCMDir%" (
	FOR /F "usebackq skip=2 tokens=3,4*" %%D IN (`REG QUERY %KEY_NAME32% /v %VALUE_NAME% 2^>nul`) DO (
		set BaseSCCMDir=%%F
	)
)

IF NOT EXIST "%BaseSCCMDir%" (
	IF NOT "%ProgramFiles(x86)%"=="" (
		set BaseSCCMDir=C:\Progra~2%ADMINCONSOLEPATH%
	) ELSE (
		set BaseSCCMDir=C:\Progra~1%ADMINCONSOLEPATH%
	)
)

SET TargetMsgsDir=%BaseSCCMDir%bin\i386\00000409\

%InstallDrive%
cd %InstallDir%

"%InstallDir%\AddSecRMMToSCCMStatusMessages.exe"

IF EXIST "%TargetMsgsDir%" (
	echo copy "%InstallDir%\Win32\secRMMSCCMMsgs.dll" "%TargetMsgsDir%secRMMSCCMMsgs.dll" /y
	copy "%InstallDir%\Win32\secRMMSCCMMsgs.dll" "%TargetMsgsDir%secRMMSCCMMsgs.dll" /y
)

IF EXIST %windir%\system32\smsmsgs (
	IF NOT "%ProgramFiles(x86)%"=="" ( 
		echo copy "%InstallDir%\x64\secRMMSCCMMsgs.dll" "%windir%\system32\smsmsgs\secRMMSCCMMsgs.dll" /y
		copy "%InstallDir%\x64\secRMMSCCMMsgs.dll" "%windir%\system32\smsmsgs\secRMMSCCMMsgs.dll" /y
	) ELSE (
		echo "%InstallDir%\Win32\secRMMSCCMMsgs.dll" "%windir%\system32\smsmsgs\secRMMSCCMMsgs.dll" /y
		copy "%InstallDir%\Win32\secRMMSCCMMsgs.dll" "%windir%\system32\smsmsgs\secRMMSCCMMsgs.dll" /y
	)
)